Cognite PowerOps SDK
==========================
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)

[Documentation](https://cognite-power-ops-sdk.readthedocs-hosted.com/en/latest/)

## Installation

To install this package:
```bash
$ pip install cognite-power-ops
```
